#!/usr/bin/env python
# coding=utf-8
"""
Copyright 2022-2023 Advanced Micro Devices Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from xdputil_component import *
import xdputil_component


def main():
    import argparse

    parser = argparse.ArgumentParser(description="xilinx tools")
    parser.add_argument("-v",
                        "--version",
                        action="version",
                        version="%(prog)s 1.0")
    subparsers = parser.add_subparsers(title="sub command ",
                                       description="xmodel tools",
                                       help="sub-command help")
    for i in xdputil_component.__all__:
        m = getattr(xdputil_component, i)
        m.help(subparsers)
    args = parser.parse_args()

    args.func(args)


if __name__ == "__main__":
    main()



#!/usr/bin/env python
# coding=utf-8
"""
Copyright 2022-2023 Advanced Micro Devices Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from typing import List
import numpy as np
import xir
import vart
import tools_extra_ops as tools
import os


def fillin_inputs(file_path_list: List["string"], tensor: "ndarray"):
    input_shape = tuple(tensor.shape[1:])
    for i in range(tensor.shape[0]):
        tensor[i, ...] = np.fromfile(file_path_list[i % len(file_path_list)],
                                     dtype=tensor.dtype,
                                     count=np.prod(input_shape)).reshape(input_shape)


def dump_outputs(outputs: List["ndarray"], tensors: List["Tensor"]):
    for output, tensor in zip(outputs, tensors):
        tensor_name = tools.remove_xfix(tensor.name).replace("/", "_")
        for batch_idx in range(output.shape[0]):
            output_file = str(batch_idx) + "." + tensor_name + ".bin"
            print("dump output to ", output_file)
            output[batch_idx, ...].tofile(output_file)


def run(subgraph: "Subgraph", args):
    # create runner
    runner = vart.Runner.create_runner(subgraph, args.runner_mode)

    # get input&output tensors
    inputTensors = runner.get_input_tensors()
    outputTensors = runner.get_output_tensors()
    inputs = [
        np.empty(tuple(t.dims), dtype=t.dtype.lstrip("x"), order="C")
        for t in inputTensors
    ]
    outputs = [
        np.empty(tuple(t.dims), dtype=t.dtype.lstrip("x"), order="C")
        for t in outputTensors
    ]

    order_inputs = list(inputTensors)
    order = sorted(range(len(order_inputs)), key=lambda k: order_inputs[k].name)

    # fillin input data
    for i in range(len(inputTensors)):
        print("fillin", inputTensors[order[i]].name)
        fillin_inputs(args.input_bin[i::len(inputTensors)], inputs[order[i]])

    # run runner
    v = runner.execute_async(inputs, outputs)
    status = runner.wait(v)
    assert status == 0, "failed to run runner"

    dump_outputs(outputs, outputTensors)


def main(args):
    # get subgraph
    graph = xir.Graph.deserialize(args.xmodel)
    assert graph is not None, "'graph' should not be None."
    subgraph = graph.get_root_subgraph()
    assert (subgraph is not None), "Failed to get root subgraph of input Graph object."

    if args.subgraph_index >= 0:
        child_subgraphs = subgraph.toposort_child_subgraph()
        assert (len(child_subgraphs) > args.subgraph_index
                ), "cannot get child_subgraph[" + str(args.subgraph_index) + "]"
        subgraph = child_subgraphs[args.subgraph_index]
        disable_vart_cpu_runner = os.getenv("USE_VART_CPU_RUNNER", "null") == "null"
        if subgraph.has_attr("device") and subgraph.get_attr(
                "device").upper() == "CPU" and disable_vart_cpu_runner:
            subgraph.set_attr("runner", {"run": "libvitis_ai_library-cpu_task.so.3"})
    else:
        if not subgraph.has_attr("device"):
            subgraph.set_attr("device", "graph")
        if not subgraph.has_attr("runner"):
            subgraph.set_attr("runner", {"run": "libvitis_ai_library-graph_runner.so.3"})
    run(subgraph, args)


def help(subparsers):
    parser = subparsers.add_parser(
        "run",
        help=
        "<xmodel> [-i <subgraph_index>] [-r <run or ref or sim>] <input_tensor_0_bin_0> "
        + "[input_tensor_1_bin_0 input_tensor_0_bin_1 input_tensor_1_bin_1 ... ]",
    )
    parser.add_argument("xmodel", help="xmodel file path ")
    parser.add_argument("-i",
                        "--subgraph_index",
                        type=int,
                        default=1,
                        help="<subgraph_index>")
    parser.add_argument("-r",
                        "--runner_mode",
                        type=str,
                        default="run",
                        help="<run or ref or sim>")
    parser.add_argument("input_bin", nargs="+", help="input_bin")
    parser.set_defaults(func=main)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vitis/ai/proto/dpu_model_param.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$vitis/ai/proto/dpu_model_param.proto\x12\x0evitis.ai.proto\"\x9c\x02\n\x0bYoloV3Param\x12\x13\n\x0bnum_classes\x18\x01 \x01(\x05\x12\x11\n\tanchorCnt\x18\x02 \x01(\x05\x12\x16\n\x0e\x63onf_threshold\x18\x03 \x01(\x02\x12\x15\n\rnms_threshold\x18\x04 \x01(\x02\x12\x0e\n\x06\x62iases\x18\x05 \x03(\x02\x12\x10\n\x08test_mAP\x18\x06 \x01(\x08\x12\x12\n\nlayer_name\x18\x07 \x03(\t\x12.\n\x04type\x18\x08 \x01(\x0e\x32 .vitis.ai.proto.YoloV3Param.Type\x12\x10\n\x08iou_type\x18\t \x01(\x05\">\n\x04Type\x12\n\n\x06NORMAL\x10\x00\x12\x0e\n\nYOLOV4_CSP\x10\x01\x12\n\n\x06YOLOV5\x10\x02\x12\x0e\n\nYOLOX_NANO\x10\x03\"\x9f\x01\n\x14MedicalPriorBoxParam\x12\x13\n\x0binput_shape\x18\x01 \x03(\x05\x12\x16\n\x0e\x66\x65\x61ture_shapes\x18\x02 \x03(\x05\x12\x11\n\tmin_sizes\x18\x03 \x03(\x05\x12\x11\n\tmax_sizes\x18\x04 \x03(\x05\x12\x15\n\raspect_ratios\x18\x05 \x03(\x02\x12\r\n\x05steps\x18\x06 \x03(\x05\x12\x0e\n\x06offset\x18\x07 \x01(\x02\"\xdf\x01\n\rPriorBoxParam\x12\x13\n\x0blayer_width\x18\x01 \x01(\x05\x12\x14\n\x0clayer_height\x18\x02 \x01(\x05\x12\x11\n\tvariances\x18\x04 \x03(\x02\x12\x11\n\tmin_sizes\x18\x05 \x03(\x02\x12\x11\n\tmax_sizes\x18\x06 \x03(\x02\x12\x15\n\raspect_ratios\x18\x07 \x03(\x02\x12\x0e\n\x06offset\x18\x08 \x01(\x02\x12\x12\n\nstep_width\x18\t \x01(\x02\x12\x13\n\x0bstep_height\x18\n \x01(\x02\x12\x0c\n\x04\x66lip\x18\x0b \x01(\x08\x12\x0c\n\x04\x63lip\x18\x0c \x01(\x08\"\xad\x03\n\x08SSDParam\x12\x36\n\x0fprior_box_param\x18\x01 \x03(\x0b\x32\x1d.vitis.ai.proto.PriorBoxParam\x12\x13\n\x0bnum_classes\x18\x02 \x01(\x05\x12\x15\n\rnms_threshold\x18\x03 \x01(\x02\x12\x16\n\x0e\x63onf_threshold\x18\x04 \x03(\x02\x12\x12\n\nkeep_top_k\x18\x05 \x01(\x05\x12\r\n\x05top_k\x18\x06 \x01(\x05\x12\x11\n\tis_mlperf\x18\x07 \x01(\x08\x12\x18\n\x10\x62\x62ox_layer_index\x18\x08 \x03(\x05\x12\x38\n\x0boutput_info\x18\t \x03(\x0b\x32#.vitis.ai.proto.SSDParam.OutputInfo\x1a\\\n\nOutputInfo\x12\x31\n\x04type\x18\x01 \x01(\x0e\x32#.vitis.ai.proto.SSDParam.OutputType\x12\r\n\x05order\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\"=\n\nOutputType\x12\x0b\n\x07USELESS\x10\x00\x12\x08\n\x04\x43ONF\x10\x01\x12\x08\n\x04\x42\x42OX\x10\x02\x12\x0e\n\nFUNCTIONAL\x10\x03\"e\n\x0eRetinaNetParam\x12\x15\n\rbox_threshold\x18\x01 \x01(\x02\x12\x15\n\rnms_threshold\x18\x02 \x01(\x02\x12\x16\n\x0e\x63onf_threshold\x18\x03 \x01(\x02\x12\r\n\x05top_k\x18\x04 \x01(\x05\"t\n\x0c\x46\x61irMotParam\x12\x15\n\rnms_threshold\x18\x01 \x01(\x02\x12\x16\n\x0e\x63onf_threshold\x18\x02 \x01(\x02\x12\x12\n\nkeep_top_k\x18\x03 \x01(\x05\x12\r\n\x05top_k\x18\x04 \x01(\x05\x12\x12\n\nlayer_name\x18\x05 \x03(\t\"Q\n\x0cMovenetParam\x12\x16\n\x0e\x63onf_threshold\x18\x01 \x01(\x02\x12\x12\n\nlayer_name\x18\x02 \x03(\t\x12\x15\n\rcenter_weight\x18\x03 \x03(\x02\"\xc3\x01\n\x0eRefineDetParam\x12\x36\n\x0fprior_box_param\x18\x01 \x03(\x0b\x32\x1d.vitis.ai.proto.PriorBoxParam\x12\x13\n\x0bnum_classes\x18\x02 \x01(\x05\x12\x15\n\rnms_threshold\x18\x03 \x01(\x02\x12\x16\n\x0e\x63onf_threshold\x18\x04 \x03(\x02\x12\x12\n\nkeep_top_k\x18\x05 \x01(\x05\x12\r\n\x05top_k\x18\x06 \x01(\x05\x12\x12\n\nlayer_name\x18\x07 \x03(\t\"\xf0\x01\n\x10TFRefineDetParam\x12=\n\x0fprior_box_param\x18\x01 \x01(\x0b\x32$.vitis.ai.proto.MedicalPriorBoxParam\x12\x13\n\x0bnum_classes\x18\x02 \x01(\x05\x12\x15\n\rnms_threshold\x18\x03 \x01(\x02\x12\x16\n\x0e\x63onf_threshold\x18\x04 \x01(\x02\x12\x12\n\nkeep_top_k\x18\x05 \x01(\x05\x12\r\n\x05top_k\x18\x06 \x01(\x05\x12\x12\n\nlayer_name\x18\x07 \x03(\t\x12\x10\n\x08scale_xy\x18\x08 \x01(\x02\x12\x10\n\x08scale_wh\x18\t \x01(\x02\"\xee\x03\n\x15MedicalRefineDetParam\x12\x13\n\x0bnum_classes\x18\x01 \x01(\x05\x12\x10\n\x08scale_xy\x18\x02 \x01(\x02\x12\x10\n\x08scale_wh\x18\x03 \x01(\x02\x12\x15\n\rnms_threshold\x18\x04 \x01(\x02\x12\x16\n\x0e\x63onf_threshold\x18\x05 \x01(\x02\x12\x12\n\nkeep_top_k\x18\x06 \x01(\x05\x12\r\n\x05top_k\x18\x07 \x01(\x05\x12\x45\n\x17medical_prior_box_param\x18\x08 \x01(\x0b\x32$.vitis.ai.proto.MedicalPriorBoxParam\x12\x45\n\x0boutput_info\x18\t \x03(\x0b\x32\x30.vitis.ai.proto.MedicalRefineDetParam.OutputInfo\x1ai\n\nOutputInfo\x12>\n\x04type\x18\x01 \x01(\x0e\x32\x30.vitis.ai.proto.MedicalRefineDetParam.OutputType\x12\r\n\x05order\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\"Q\n\nOutputType\x12\x0b\n\x07USELESS\x10\x00\x12\x0c\n\x08\x41RM_CONF\x10\x01\x12\x0c\n\x08\x41RM_BBOX\x10\x02\x12\x0c\n\x08ODM_CONF\x10\x03\x12\x0c\n\x08ODM_BBOX\x10\x04\"B\n\tReidParam\x12\x10\n\x08\x62n_means\x18\x01 \x03(\x02\x12\x12\n\nbn_weights\x18\x02 \x03(\x02\x12\x0f\n\x07\x62n_vars\x18\x03 \x03(\x02\"#\n\rOpenPoseParam\x12\x12\n\nlayer_name\x18\x01 \x03(\t\"\x90\x04\n\x13\x43lassificationParam\x12\r\n\x05top_k\x18\x01 \x01(\x05\x12\x15\n\rtest_accuracy\x18\x02 \x01(\x08\x12K\n\x0fpreprocess_type\x18\x03 \x01(\x0e\x32\x32.vitis.ai.proto.ClassificationParam.PreprocessType\x12\x12\n\nlayer_name\x18\x04 \x01(\t\x12\x12\n\nlabel_type\x18\x05 \x01(\t\x12H\n\x0e\x61vg_pool_param\x18\x06 \x01(\x0b\x32\x30.vitis.ai.proto.ClassificationParam.AvgPoolParam\x1a\x1d\n\x0c\x41vgPoolParam\x12\r\n\x05scale\x18\x01 \x01(\x05\"\xf4\x01\n\x0ePreprocessType\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\t\n\x05\x43\x41\x46\x46\x45\x10\x01\x12\x12\n\x0eVGG_PREPROCESS\x10\x02\x12\x18\n\x14INCEPTION_PREPROCESS\x10\x03\x12\x10\n\x0cINCEPTION_PT\x10\x04\x12\x10\n\x0cRESNET50_TF2\x10\x05\x12\x1b\n\x17\x45\x46\x46ICIENTNET_PREPROCESS\x10\x06\x12\x13\n\x0fOFA_RESNET50_PT\x10\x07\x12\x17\n\x13OFA_DEPTHWISE_RES50\x10\x08\x12\x12\n\x0eRGB_PREPROCESS\x10\t\x12\x14\n\x10OFA_RESNET50_PT2\x10\n\"U\n\rDenseBoxParam\x12\x16\n\x0enum_of_classes\x18\x01 \x01(\x05\x12\x15\n\rnms_threshold\x18\x02 \x01(\x02\x12\x15\n\rdet_threshold\x18\x03 \x01(\x02\"\xe8\x02\n\x0eMultiTaskParam\x12\x0f\n\x07th_conf\x18\x01 \x03(\x02\x12 \n\x18num_of_detection_classes\x18\x02 \x01(\x05\x12#\n\x1bnum_of_segmentation_classes\x18\x03 \x01(\x05\x12\x12\n\nkeep_top_k\x18\x04 \x01(\x05\x12\r\n\x05top_k\x18\x05 \x01(\x05\x12\x15\n\rnms_threshold\x18\x06 \x01(\x02\x12\x36\n\x0fprior_box_param\x18\x07 \x03(\x0b\x32\x1d.vitis.ai.proto.PriorBoxParam\x12\x10\n\x08loc_name\x18\x08 \x03(\t\x12\x11\n\tconf_name\x18\t \x03(\t\x12\x17\n\x0f\x63\x65nterness_name\x18\n \x03(\t\x12\x10\n\x08seg_name\x18\x0b \x01(\t\x12\x15\n\rdrivable_name\x18\x0c \x01(\t\x12\x12\n\ndepth_name\x18\r \x01(\t\x12\x11\n\tlane_name\x18\x0e \x01(\t\"\xed\x02\n\rRoadlineParam\x12\r\n\x05ratio\x18\x01 \x01(\x05\x12\x11\n\tipm_width\x18\x02 \x01(\x02\x12\x12\n\nipm_height\x18\x03 \x01(\x02\x12\x10\n\x08ipm_left\x18\x04 \x01(\x02\x12\x11\n\tipm_right\x18\x05 \x01(\x02\x12\x0f\n\x07ipm_top\x18\x06 \x01(\x02\x12\x12\n\nipm_bottom\x18\x07 \x01(\x02\x12\x19\n\x11ipm_interpolation\x18\x08 \x01(\x02\x12\x16\n\x0eipm_vp_portion\x18\t \x01(\x02\x12\x16\n\x0e\x66ocal_length_x\x18\n \x01(\x02\x12\x16\n\x0e\x66ocal_length_y\x18\x0b \x01(\x02\x12\x18\n\x10optical_center_x\x18\x0c \x01(\x02\x12\x18\n\x10optical_center_y\x18\r \x01(\x02\x12\x15\n\rcamera_height\x18\x0e \x01(\x02\x12\r\n\x05pitch\x18\x0f \x01(\x02\x12\x0b\n\x03yaw\x18\x10 \x01(\x02\x12\x12\n\nlayer_name\x18\x11 \x03(\t\"\x1a\n\tRcanParam\x12\r\n\x05scale\x18\x01 \x01(\x02\"\x9f\x01\n\x13RoadlineDeephiParam\x12\x10\n\x08resize_w\x18\x01 \x01(\x05\x12\x10\n\x08resize_h\x18\x02 \x01(\x05\x12\x0e\n\x06\x63rop_x\x18\x03 \x01(\x05\x12\x0e\n\x06\x63rop_y\x18\x04 \x01(\x05\x12\x0e\n\x06\x63rop_w\x18\x05 \x01(\x05\x12\x0e\n\x06\x63rop_h\x18\x06 \x01(\x05\x12\x16\n\x0e\x61rea_threshold\x18\x07 \x01(\x05\x12\x0c\n\x04\x65pow\x18\x08 \x01(\x05\"}\n\x11SegmentationParam\x12\x0e\n\x06\x63olor1\x18\x01 \x01(\t\x12\x0e\n\x06\x63olor2\x18\x02 \x01(\t\x12\x0e\n\x06\x63olor3\x18\x03 \x01(\t\x12\x1c\n\x14specify_output_layer\x18\x04 \x01(\x08\x12\x1a\n\x12output_tensor_name\x18\x05 \x01(\t\"J\n\rPlatenumParam\x12\r\n\x05\x66irst\x18\x01 \x03(\x05\x12\x0e\n\x06second\x18\x02 \x03(\x05\x12\x1a\n\x12output_tensor_name\x18\x03 \x03(\t\"\xc0\x01\n\tSoloParam\x12\r\n\x05\x66irst\x18\x01 \x03(\x05\x12\x0e\n\x06second\x18\x02 \x03(\x05\x12\x19\n\x11input_tensor_name\x18\x03 \x03(\t\x12\x1a\n\x12output_tensor_name\x18\x04 \x03(\t\x12\x11\n\tscore_thr\x18\x05 \x01(\x02\x12\x10\n\x08mask_thr\x18\x06 \x01(\x02\x12\x0f\n\x07nms_pre\x18\x07 \x01(\r\x12\x12\n\nupdate_thr\x18\x08 \x01(\x02\x12\x13\n\x0bmax_per_img\x18\t \x01(\r\"@\n\tLaneParam\x12\r\n\x05roi_x\x18\x01 \x01(\x05\x12\r\n\x05roi_y\x18\x02 \x01(\x05\x12\x15\n\rexpect_height\x18\x03 \x01(\x05\"\xad\x01\n\x0c\x42linkerParam\x12\x36\n\x0fprior_box_param\x18\x01 \x03(\x0b\x32\x1d.vitis.ai.proto.PriorBoxParam\x12\x13\n\x0bnum_classes\x18\x02 \x01(\x05\x12\x15\n\rnms_threshold\x18\x03 \x01(\x02\x12\x16\n\x0e\x63onf_threshold\x18\x04 \x03(\x02\x12\x12\n\nkeep_top_k\x18\x05 \x01(\x05\x12\r\n\x05top_k\x18\x06 \x01(\x05\"\xac\x01\n\x0bSegdetParam\x12\x36\n\x0fprior_box_param\x18\x01 \x03(\x0b\x32\x1d.vitis.ai.proto.PriorBoxParam\x12\x13\n\x0bnum_classes\x18\x02 \x01(\x05\x12\x15\n\rnms_threshold\x18\x03 \x01(\x02\x12\x16\n\x0e\x63onf_threshold\x18\x04 \x03(\x02\x12\x12\n\nkeep_top_k\x18\x05 \x01(\x05\x12\r\n\x05top_k\x18\x06 \x01(\x05\"\x81\x01\n\x13\x46\x61\x63\x65Quality5ptParam\x12\x1a\n\x12use_day_night_mode\x18\x01 \x01(\x08\x12\x18\n\x10original_quality\x18\x02 \x01(\x08\x12\x1a\n\x12quality_layer_name\x18\x03 \x01(\t\x12\x18\n\x10point_layer_name\x18\x04 \x01(\t\"\x82\x05\n\x0fRetinaFaceParam\x12?\n\x0boutput_info\x18\x01 \x03(\x0b\x32*.vitis.ai.proto.RetinaFaceParam.OutputInfo\x12\x15\n\rnms_threshold\x18\x02 \x01(\x02\x12\x15\n\rdet_threshold\x18\x03 \x01(\x02\x12\x41\n\x0c\x61nchor_param\x18\x04 \x03(\x0b\x32+.vitis.ai.proto.RetinaFaceParam.AnchorParam\x1a[\n\x10OutputAnchorInfo\x12\x38\n\x04type\x18\x01 \x01(\x0e\x32*.vitis.ai.proto.RetinaFaceParam.AnchorType\x12\r\n\x05index\x18\x02 \x01(\x05\x1a\xb2\x01\n\nOutputInfo\x12\x38\n\x04type\x18\x01 \x01(\x0e\x32*.vitis.ai.proto.RetinaFaceParam.OutputType\x12\x0e\n\x06stride\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\x12L\n\x12output_anchor_info\x18\x04 \x01(\x0b\x32\x30.vitis.ai.proto.RetinaFaceParam.OutputAnchorInfo\x1aP\n\x0b\x41nchorParam\x12\x0e\n\x06stride\x18\x01 \x01(\x05\x12\x11\n\tbase_size\x18\x02 \x01(\x05\x12\x0e\n\x06ratios\x18\x03 \x03(\x02\x12\x0e\n\x06scales\x18\x04 \x03(\x05\";\n\nOutputType\x12\x0b\n\x07USELESS\x10\x00\x12\x08\n\x04\x43ONF\x10\x01\x12\x08\n\x04\x42\x42OX\x10\x02\x12\x0c\n\x08LANDMARK\x10\x03\"\x1c\n\nAnchorType\x12\x06\n\x02\x42G\x10\x00\x12\x06\n\x02\x46G\x10\x01\";\n\x0e\x44puKernelParam\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04mean\x18\x02 \x03(\x02\x12\r\n\x05scale\x18\x03 \x03(\x02\"\xf1\x01\n\nTfssdParam\x12:\n\x0boutput_info\x18\x01 \x03(\x0b\x32%.vitis.ai.proto.TfssdParam.OutputInfo\x12\x18\n\x10\x66\x65\x61ture_map_list\x18\x02 \x03(\x05\x1a^\n\nOutputInfo\x12\x33\n\x04type\x18\x01 \x01(\x0e\x32%.vitis.ai.proto.TfssdParam.OutputType\x12\r\n\x05order\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\"-\n\nOutputType\x12\x0b\n\x07USELESS\x10\x00\x12\x08\n\x04\x43ONF\x10\x01\x12\x08\n\x04\x42\x42OX\x10\x02\"\xa7\x05\n\x14PointPillarsNusParam\x12\x19\n\x11point_cloud_range\x18\x01 \x03(\x02\x12\x13\n\x0bin_channels\x18\x02 \x01(\x05\x12\x16\n\x0emax_points_num\x18\x03 \x01(\x05\x12\x16\n\x0emax_voxels_num\x18\x04 \x01(\x05\x12\x14\n\x0c\x66\x65\x61tmap_size\x18\x05 \x03(\x05\x12\x44\n\x0b\x61nchor_info\x18\x06 \x01(\x0b\x32/.vitis.ai.proto.PointPillarsNusParam.AnchorInfo\x12\x13\n\x0bnum_classes\x18\x07 \x01(\x05\x12\x0f\n\x07nms_pre\x18\x08 \x01(\x02\x12\x12\n\nnms_thresh\x18\t \x01(\x02\x12\x0f\n\x07max_num\x18\n \x01(\x02\x12\x14\n\x0cscore_thresh\x18\x0b \x01(\x02\x12\x18\n\x10score_layer_name\x18\x0c \x01(\t\x12\x17\n\x0f\x62\x62ox_layer_name\x18\r \x01(\t\x12\x16\n\x0e\x64ir_layer_name\x18\x0e \x01(\t\x1a\xa6\x02\n\nAnchorInfo\x12\x46\n\x06ranges\x18\x01 \x03(\x0b\x32\x36.vitis.ai.proto.PointPillarsNusParam.AnchorInfo.Ranges\x12\x44\n\x05sizes\x18\x02 \x03(\x0b\x32\x35.vitis.ai.proto.PointPillarsNusParam.AnchorInfo.Sizes\x12\x11\n\trotations\x18\x03 \x03(\x02\x12\x14\n\x0c\x63ustom_value\x18\x04 \x03(\x02\x12\x14\n\x0c\x61lign_corner\x18\x05 \x01(\x08\x12\r\n\x05scale\x18\x06 \x01(\x02\x1a\x1e\n\x06Ranges\x12\x14\n\x0csingle_range\x18\x01 \x03(\x02\x1a\x1c\n\x05Sizes\x12\x13\n\x0bsingle_size\x18\x01 \x03(\x02\")\n\x13Segmentation3DParam\x12\x12\n\nenable_knn\x18\x01 \x01(\x08\"z\n\x0bYoloV5Param\x12/\n\nyolo_param\x18\x01 \x01(\x0b\x32\x1b.vitis.ai.proto.YoloV3Param\x12\x0e\n\x06stride\x18\x02 \x03(\x02\x12\x15\n\rmax_boxes_num\x18\x03 \x01(\x02\x12\x13\n\x0bmax_nms_num\x18\x04 \x01(\x02\"\x88\x02\n\x0bYoloV6Param\x12\x13\n\x0bnum_classes\x18\x01 \x01(\x05\x12\x11\n\tanchorCnt\x18\x02 \x01(\x05\x12\x16\n\x0e\x63onf_threshold\x18\x03 \x01(\x02\x12\x15\n\rnms_threshold\x18\x04 \x01(\x02\x12\x0e\n\x06\x62iases\x18\x05 \x03(\x02\x12\x10\n\x08test_mAP\x18\x06 \x01(\x08\x12\x17\n\x0f\x62\x62ox_layer_name\x18\x07 \x03(\t\x12\x16\n\x0e\x63ls_layer_name\x18\x08 \x03(\t\x12\x0e\n\x06stride\x18\t \x03(\x02\x12\x15\n\rmax_boxes_num\x18\n \x01(\x02\x12\x13\n\x0bmax_nms_num\x18\x0b \x01(\x02\x12\x13\n\x0bwithout_dfl\x18\x0c \x01(\x08\"y\n\x0bYoloV7Param\x12\x13\n\x0b\x63onf_thresh\x18\x01 \x01(\x02\x12\x15\n\rnms_threshold\x18\x02 \x01(\x02\x12\x13\n\x0bnum_classes\x18\x03 \x01(\x05\x12\x19\n\x11\x64\x65tect_layer_name\x18\x04 \x03(\t\x12\x0e\n\x06\x62iases\x18\x05 \x03(\x02\"\xa5\x01\n\x0bYoloV8Param\x12\x13\n\x0b\x63onf_thresh\x18\x01 \x01(\x02\x12\x15\n\rmax_boxes_num\x18\x02 \x01(\x02\x12\x15\n\rnms_threshold\x18\x03 \x01(\x02\x12\x13\n\x0bmax_nms_num\x18\x04 \x01(\x02\x12\x13\n\x0bnum_classes\x18\x05 \x01(\x05\x12\x19\n\x11\x64\x65tect_layer_name\x18\x06 \x03(\t\x12\x0e\n\x06stride\x18\x07 \x03(\x02\"\xe0\x01\n\tFcosParam\x12\x16\n\x0epre_nms_thresh\x18\x01 \x01(\x02\x12\x15\n\rpre_nms_top_n\x18\x02 \x01(\x05\x12\x15\n\rnms_threshold\x18\x03 \x01(\x02\x12\x1a\n\x12\x66pn_post_nms_top_n\x18\x04 \x01(\x02\x12\x13\n\x0bnum_classes\x18\x05 \x01(\x05\x12\x19\n\x11\x63\x65nter_layer_name\x18\x06 \x03(\t\x12\x16\n\x0e\x63ls_layer_name\x18\x07 \x03(\t\x12\x19\n\x11offset_layer_name\x18\x08 \x03(\t\x12\x0e\n\x06stride\x18\t \x03(\x02\"}\n\x08\x42TSParam\x12\x12\n\nmul_factor\x18\x01 \x01(\x02\x12\x1b\n\x13\x64\x65pth_scaled_factor\x18\x02 \x01(\x02\x12!\n\x19hard_sigmoid_output_scale\x18\x03 \x01(\x02\x12\x1d\n\x15multiple_output_scale\x18\x04 \x01(\x02\"\x9f\x01\n\x15PointPillarsBaseParam\x12\x19\n\x11point_cloud_range\x18\x01 \x03(\x02\x12\x12\n\nvoxel_size\x18\x02 \x03(\x02\x12\x12\n\npoints_dim\x18\x03 \x01(\x05\x12\x16\n\x0emax_points_num\x18\x04 \x01(\x05\x12\x16\n\x0emax_voxels_num\x18\x05 \x01(\x05\x12\x13\n\x0bin_channels\x18\x06 \x01(\x05\"M\n\x16PointPillarsKittiParam\x12\x33\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32%.vitis.ai.proto.PointPillarsBaseParam\"\xea\x04\n\x13X_Autonomous3DParam\x12\x19\n\x11point_cloud_range\x18\x01 \x03(\x02\x12\x12\n\nvoxel_size\x18\x02 \x03(\x02\x12\x12\n\npoints_dim\x18\x03 \x01(\x05\x12\x16\n\x0emax_points_num\x18\x04 \x01(\x05\x12\x16\n\x0emax_voxels_num\x18\x05 \x01(\x05\x12\x13\n\x0bin_channels\x18\x06 \x01(\x05\x12P\n\x0coutput_names\x18\x07 \x01(\x0b\x32:.vitis.ai.proto.X_Autonomous3DParam.CenterPointOutputLayer\x12\x13\n\x0bnum_classes\x18\x08 \x01(\x05\x12\x17\n\x0fout_size_facter\x18\t \x01(\x02\x12\x19\n\x11iou_quality_alpha\x18\n \x03(\x02\x12\x1e\n\x16post_point_cloud_range\x18\x0b \x03(\x02\x12\x15\n\rbbox_pre_size\x18\x0c \x01(\x05\x12\x15\n\rbbox_max_size\x18\r \x01(\x05\x12\x12\n\nnms_thresh\x18\x0e \x03(\x02\x12\x14\n\x0cscore_thresh\x18\x0f \x01(\x02\x1a\xb7\x01\n\x16\x43\x65nterPointOutputLayer\x12\x16\n\x0ereg_layer_name\x18\x01 \x01(\t\x12\x19\n\x11height_layer_name\x18\x02 \x01(\t\x12\x16\n\x0e\x64im_layer_name\x18\x03 \x01(\t\x12\x16\n\x0erot_layer_name\x18\x04 \x01(\t\x12\x1a\n\x12heatmap_layer_name\x18\x05 \x01(\t\x12\x1e\n\x16iou_quality_layer_name\x18\x06 \x01(\t\"\xc9\x04\n\x13\x45\x66\x66icientDetD2Param\x12\x43\n\x0b\x61nchor_info\x18\x01 \x01(\x0b\x32..vitis.ai.proto.EfficientDetD2Param.AnchorInfo\x12\x13\n\x0bnum_classes\x18\x02 \x01(\x05\x12\x13\n\x0bpre_nms_num\x18\x03 \x01(\x05\x12\x15\n\rnms_threshold\x18\x04 \x01(\x02\x12\x16\n\x0e\x63onf_threshold\x18\x05 \x01(\x02\x12\x16\n\x0enms_output_num\x18\x06 \x01(\x05\x12\x43\n\x0boutput_info\x18\x07 \x03(\x0b\x32..vitis.ai.proto.EfficientDetD2Param.OutputInfo\x1ag\n\nOutputInfo\x12<\n\x04type\x18\x01 \x01(\x0e\x32..vitis.ai.proto.EfficientDetD2Param.OutputType\x12\r\n\x05level\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\x1a\x9e\x01\n\nAnchorInfo\x12\x11\n\tmin_level\x18\x01 \x01(\x05\x12\x11\n\tmax_level\x18\x02 \x01(\x05\x12\x12\n\nnum_scales\x18\x03 \x01(\x05\x12\x15\n\ranchor_scales\x18\x04 \x03(\x02\x12\x14\n\x0c\x61spect_ratio\x18\x05 \x03(\x02\x12\x13\n\x0bimage_width\x18\x06 \x01(\x05\x12\x14\n\x0cimage_height\x18\x07 \x01(\x05\"-\n\nOutputType\x12\x0b\n\x07USELESS\x10\x00\x12\x08\n\x04\x43ONF\x10\x01\x12\x08\n\x04\x42\x42OX\x10\x02\"\xc6\x01\n\rSubgraphParam\x12\x0e\n\x06\x63ycles\x18\x01 \x01(\x05\x12\x14\n\x0csubgraph_idx\x18\x02 \x01(\t\x12\x37\n\x05input\x18\x03 \x03(\x0b\x32(.vitis.ai.proto.SubgraphParam.InputParam\x1aV\n\nInputParam\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1a\n\x12previous_model_idx\x18\x02 \x01(\x05\x12\x1e\n\x16previous_output_tensor\x18\x03 \x01(\t\"\xb2\x19\n\rDpuModelParam\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\x06kernel\x18\x02 \x03(\x0b\x32\x1e.vitis.ai.proto.DpuKernelParam\x12\x18\n\x10use_graph_runner\x18\x1c \x01(\x08\x12;\n\nmodel_type\x18\x03 \x01(\x0e\x32\'.vitis.ai.proto.DpuModelParam.ModelType\x12\x38\n\x10refine_det_param\x18\x04 \x01(\x0b\x32\x1e.vitis.ai.proto.RefineDetParam\x12\x32\n\ryolo_v3_param\x18\x05 \x01(\x0b\x32\x1b.vitis.ai.proto.YoloV3Param\x12+\n\tssd_param\x18\x06 \x01(\x0b\x32\x18.vitis.ai.proto.SSDParam\x12\x41\n\x14\x63lassification_param\x18\x07 \x01(\x0b\x32#.vitis.ai.proto.ClassificationParam\x12\x36\n\x0f\x64\x65nse_box_param\x18\x08 \x01(\x0b\x32\x1d.vitis.ai.proto.DenseBoxParam\x12\x38\n\x10multi_task_param\x18\t \x01(\x0b\x32\x1e.vitis.ai.proto.MultiTaskParam\x12\x35\n\x0eroadline_param\x18\n \x01(\x0b\x32\x1d.vitis.ai.proto.RoadlineParam\x12=\n\x12segmentation_param\x18\x0b \x01(\x0b\x32!.vitis.ai.proto.SegmentationParam\x12-\n\nlane_param\x18\x0c \x01(\x0b\x32\x19.vitis.ai.proto.LaneParam\x12\x33\n\rblinker_param\x18\r \x01(\x0b\x32\x1c.vitis.ai.proto.BlinkerParam\x12\x31\n\x0csegdet_param\x18\x0e \x01(\x0b\x32\x1b.vitis.ai.proto.SegdetParam\x12>\n\x11roadline_dp_param\x18\x0f \x01(\x0b\x32#.vitis.ai.proto.RoadlineDeephiParam\x12\r\n\x05is_tf\x18\x10 \x01(\x08\x12\x42\n\x15\x66\x61\x63\x65_quality5pt_param\x18\x11 \x01(\x0b\x32#.vitis.ai.proto.FaceQuality5ptParam\x12/\n\x0btfssd_param\x18\x12 \x01(\x0b\x32\x1a.vitis.ai.proto.TfssdParam\x12\x36\n\x0fopen_pose_param\x18\x13 \x01(\x0b\x32\x1d.vitis.ai.proto.OpenPoseParam\x12-\n\nreid_param\x18\x14 \x01(\x0b\x32\x19.vitis.ai.proto.ReidParam\x12G\n\x18medical_refine_det_param\x18\x15 \x01(\x0b\x32%.vitis.ai.proto.MedicalRefineDetParam\x12\x35\n\x0eplatenum_param\x18\x16 \x01(\x0b\x32\x1d.vitis.ai.proto.PlatenumParam\x12;\n\norder_type\x18\x17 \x01(\x0e\x32\'.vitis.ai.proto.DpuModelParam.OrderType\x12\x39\n\x10retinaface_param\x18\x18 \x01(\x0b\x32\x1f.vitis.ai.proto.RetinaFaceParam\x12;\n\x11tfrefinedet_param\x18\x19 \x01(\x0b\x32 .vitis.ai.proto.TFRefineDetParam\x12\x44\n\x16pointpillars_nus_param\x18\x1a \x01(\x0b\x32$.vitis.ai.proto.PointPillarsNusParam\x12\x42\n\x15segmentation_3d_param\x18\x1b \x01(\x0b\x32#.vitis.ai.proto.Segmentation3DParam\x12\x32\n\ryolo_v5_param\x18\x1d \x01(\x0b\x32\x1b.vitis.ai.proto.YoloV5Param\x12+\n\tbts_param\x18\x1e \x01(\x0b\x32\x18.vitis.ai.proto.BTSParam\x12\x34\n\x0e\x66\x61ir_mot_param\x18\x1f \x01(\x0b\x32\x1c.vitis.ai.proto.FairMotParam\x12\x41\n\x14x_autonomous3d_param\x18  \x01(\x0b\x32#.vitis.ai.proto.X_Autonomous3DParam\x12H\n\x18pointpillars_kitti_param\x18! \x01(\x0b\x32&.vitis.ai.proto.PointPillarsKittiParam\x12-\n\nsolo_param\x18\" \x01(\x0b\x32\x19.vitis.ai.proto.SoloParam\x12/\n\x08subgraph\x18# \x03(\x0b\x32\x1d.vitis.ai.proto.SubgraphParam\x12H\n\x1bvehicleclassification_param\x18$ \x01(\x0b\x32#.vitis.ai.proto.ClassificationParam\x12\x42\n\x15\x65\x66\x66icientdet_d2_param\x18% \x01(\x0b\x32#.vitis.ai.proto.EfficientDetD2Param\x12\x33\n\rmovenet_param\x18& \x01(\x0b\x32\x1c.vitis.ai.proto.MovenetParam\x12-\n\nrcan_param\x18\' \x01(\x0b\x32\x19.vitis.ai.proto.RcanParam\x12\x32\n\ryolo_v6_param\x18( \x01(\x0b\x32\x1b.vitis.ai.proto.YoloV6Param\x12-\n\nfcos_param\x18) \x01(\x0b\x32\x19.vitis.ai.proto.FcosParam\x12\x32\n\ryolo_v8_param\x18* \x01(\x0b\x32\x1b.vitis.ai.proto.YoloV8Param\x12\x37\n\x0fretinanet_param\x18+ \x01(\x0b\x32\x1e.vitis.ai.proto.RetinaNetParam\x12\x32\n\ryolo_v7_param\x18, \x01(\x0b\x32\x1b.vitis.ai.proto.YoloV7Param\"\x8f\x06\n\tModelType\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\r\n\tREFINEDET\x10\x01\x12\x07\n\x03SSD\x10\x02\x12\n\n\x06YOLOv3\x10\x03\x12\x12\n\x0e\x43LASSIFICATION\x10\x04\x12\r\n\tDENSE_BOX\x10\x05\x12\x0e\n\nMULTI_TASK\x10\x06\x12\x0c\n\x08OPENPOSE\x10\x07\x12\x0c\n\x08ROADLINE\x10\x08\x12\x10\n\x0cSEGMENTATION\x10\t\x12\x0e\n\nPOSEDETECT\x10\n\x12\x08\n\x04LANE\x10\x0b\x12\x0b\n\x07\x42LINKER\x10\x0c\x12\n\n\x06SEGDET\x10\r\x12\x13\n\x0fROADLINE_DEEPHI\x10\x0e\x12\x12\n\x0e\x46\x41\x43\x45QUALITY5PT\x10\x0f\x12\x08\n\x04REID\x10\x10\x12\n\n\x06YOLOv2\x10\x11\x12\t\n\x05TFSSD\x10\x12\x12\x10\n\x0c\x46\x41\x43\x45LANDMARK\x10\x13\x12\x0f\n\x0bPLATEDETECT\x10\x14\x12\x0c\n\x08PLATENUM\x10\x15\x12\x0e\n\nPLATERECOG\x10\x16\x12\x0f\n\x0b\x46\x41\x43\x45\x46\x45\x41TURE\x10\x17\x12\x14\n\x10SEGMENTATION8UC1\x10\x18\x12\x14\n\x10SEGMENTATION8UC3\x10\x19\x12\x17\n\x13MEDICALSEGMENTATION\x10\x1a\x12\x11\n\rMULTITASK8UC1\x10\x1b\x12\x11\n\rMULTITASK8UC3\x10\x1c\x12\x14\n\x10MEDICALREFINEDET\x10\x1d\x12\x13\n\x0f\x46\x41\x43\x45\x44\x45TECTRECOG\x10\x1e\x12\r\n\tHOURGLASS\x10\x1f\x12\x0e\n\nRETINAFACE\x10 \x12\x0f\n\x0bTFREFINEDET\x10!\x12\x14\n\x10POINTPILLARS_NUS\x10\"\x12\n\n\x06YOLOv5\x10#\x12\x0c\n\x08\x42TSParam\x10$\x12\x0b\n\x07\x46\x41IRMOT\x10%\x12\x12\n\x0eX_AUTONOMOUS3D\x10&\x12\x10\n\x0cPOINTPILLARS\x10\'\x12\x08\n\x04SOLO\x10(\x12\x19\n\x15VEHICLECLASSIFICATION\x10)\x12\x13\n\x0f\x45\x46\x46ICIENTDET_D2\x10*\x12\x0b\n\x07MOVENET\x10+\x12\n\n\x06YOLOv6\x10,\x12\x08\n\x04\x46\x43OS\x10-\x12\n\n\x06YOLOv8\x10.\x12\n\n\x06YOLOv7\x10/\"9\n\tOrderType\x12\x10\n\x0cUNKNOWNORDER\x10\x00\x12\x07\n\x03\x42GR\x10\x01\x12\x07\n\x03RGB\x10\x02\x12\x08\n\x04GREY\x10\x03\"A\n\x11\x44puModelParamList\x12,\n\x05model\x18\x01 \x03(\x0b\x32\x1d.vitis.ai.proto.DpuModelParam\"8\n\tAttribute\x12\r\n\x05label\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\r\x12\r\n\x05score\x18\x03 \x01(\x02\"\x1d\n\x05Point\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\"%\n\x04Size\x12\r\n\x05width\x18\x01 \x01(\x02\x12\x0e\n\x06height\x18\x02 \x01(\x02\"\x8e\x01\n\x0b\x42oundingBox\x12\x32\n\x05label\x18\x01 \x01(\x0b\x32#.vitis.ai.proto.ClassificationLabel\x12\'\n\x08top_left\x18\x03 \x01(\x0b\x32\x15.vitis.ai.proto.Point\x12\"\n\x04size\x18\x04 \x01(\x0b\x32\x14.vitis.ai.proto.Size\"?\n\x0f\x41ttributeResult\x12,\n\tattribute\x18\x01 \x03(\x0b\x32\x19.vitis.ai.proto.Attribute\"b\n\x0eLandmarkResult\x12\r\n\x05score\x18\x01 \x01(\x02\x12$\n\x05point\x18\x02 \x03(\x0b\x32\x15.vitis.ai.proto.Point\x12\x0e\n\x06gender\x18\x03 \x01(\r\x12\x0b\n\x03\x61ge\x18\x04 \x01(\r\"A\n\x0c\x44\x65tectResult\x12\x31\n\x0c\x62ounding_box\x18\x01 \x03(\x0b\x32\x1b.vitis.ai.proto.BoundingBox\"C\n\rLineAttribute\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12$\n\x05point\x18\x02 \x03(\x0b\x32\x15.vitis.ai.proto.Point\"G\n\x0eRoadlineResult\x12\x35\n\x0eline_attribute\x18\x01 \x03(\x0b\x32\x1d.vitis.ai.proto.LineAttribute\"%\n\x05Score\x12\r\n\x05index\x18\x01 \x01(\x05\x12\r\n\x05score\x18\x02 \x01(\x02\"A\n\x13\x43lassificationLabel\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05index\x18\x02 \x01(\r\x12\r\n\x05score\x18\x03 \x01(\x02\"I\n\x14\x43lassificationResult\x12\x31\n\x04topk\x18\x01 \x03(\x0b\x32#.vitis.ai.proto.ClassificationLabel\":\n\x12\x46\x61\x63\x65LandmarkResult\x12$\n\x05point\x18\x01 \x03(\x0b\x32\x15.vitis.ai.proto.Point\"F\n\x11PlateDetectResult\x12\x31\n\x0c\x62ounding_box\x18\x01 \x01(\x0b\x32\x1b.vitis.ai.proto.BoundingBox\">\n\x11PlateNumberResult\x12\x14\n\x0cplate_number\x18\x01 \x01(\t\x12\x13\n\x0bplate_color\x18\x02 \x01(\t\"p\n\x10PlateRecogResult\x12\x31\n\x0c\x62ounding_box\x18\x01 \x01(\x0b\x32\x1b.vitis.ai.proto.BoundingBox\x12\x14\n\x0cplate_number\x18\x02 \x01(\t\x12\x13\n\x0bplate_color\x18\x03 \x01(\t\"\xe6\x04\n\x10PoseDetectResult\x12-\n\x0eright_shoulder\x18\x01 \x01(\x0b\x32\x15.vitis.ai.proto.Point\x12*\n\x0bright_elbow\x18\x02 \x01(\x0b\x32\x15.vitis.ai.proto.Point\x12*\n\x0bright_wrist\x18\x03 \x01(\x0b\x32\x15.vitis.ai.proto.Point\x12,\n\rleft_shoulder\x18\x04 \x01(\x0b\x32\x15.vitis.ai.proto.Point\x12)\n\nleft_elbow\x18\x05 \x01(\x0b\x32\x15.vitis.ai.proto.Point\x12)\n\nleft_wrist\x18\x06 \x01(\x0b\x32\x15.vitis.ai.proto.Point\x12(\n\tright_hip\x18\x07 \x01(\x0b\x32\x15.vitis.ai.proto.Point\x12)\n\nright_knee\x18\x08 \x01(\x0b\x32\x15.vitis.ai.proto.Point\x12*\n\x0bright_ankle\x18\t \x01(\x0b\x32\x15.vitis.ai.proto.Point\x12\'\n\x08left_hip\x18\n \x01(\x0b\x32\x15.vitis.ai.proto.Point\x12(\n\tleft_knee\x18\x0b \x01(\x0b\x32\x15.vitis.ai.proto.Point\x12)\n\nleft_ankle\x18\x0c \x01(\x0b\x32\x15.vitis.ai.proto.Point\x12#\n\x04head\x18\r \x01(\x0b\x32\x15.vitis.ai.proto.Point\x12#\n\x04neck\x18\x0e \x01(\x0b\x32\x15.vitis.ai.proto.Point\"F\n\x11\x46\x61\x63\x65\x46\x65\x61tureResult\x12\x11\n\tfloat_vec\x18\x01 \x03(\x02\x12\x0f\n\x07\x66ix_vec\x18\x02 \x01(\x0c\x12\r\n\x05scale\x18\x03 \x01(\x02\"~\n\x15\x46\x61\x63\x65\x44\x65tectRecogResult\x12\x31\n\x0c\x62ounding_box\x18\x01 \x03(\x0b\x32\x1b.vitis.ai.proto.BoundingBox\x12\x32\n\x07\x66\x65\x61ture\x18\x02 \x03(\x0b\x32!.vitis.ai.proto.FaceFeatureResult\"!\n\x11SegmetationResult\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\r\"S\n\x18MedicalSegmetationResult\x12\x37\n\x0csegmentation\x18\x01 \x03(\x0b\x32!.vitis.ai.proto.SegmetationResult\"q\n\rVehicleResult\x12\r\n\x05label\x18\x01 \x01(\x05\x12\r\n\x05score\x18\x02 \x01(\x02\x12\t\n\x01x\x18\x03 \x01(\x02\x12\t\n\x01y\x18\x04 \x01(\x02\x12\r\n\x05width\x18\x05 \x01(\x02\x12\x0e\n\x06height\x18\x06 \x01(\x02\x12\r\n\x05\x61ngle\x18\x07 \x01(\x02\"\x81\x01\n\x0fMultiTaskResult\x12\x37\n\x0csegmentation\x18\x01 \x01(\x0b\x32!.vitis.ai.proto.SegmetationResult\x12\x35\n\x0evehicle_reuslt\x18\x02 \x03(\x0b\x32\x1d.vitis.ai.proto.VehicleResult\"\x1a\n\nReidResult\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\r\"\xb5\t\n\x0e\x44puModelResult\x12\x39\n\x0flandmark_result\x18\x01 \x01(\x0b\x32\x1e.vitis.ai.proto.LandmarkResultH\x00\x12\x35\n\rdetect_result\x18\x02 \x01(\x0b\x32\x1c.vitis.ai.proto.DetectResultH\x00\x12;\n\x10\x61ttribute_result\x18\x03 \x01(\x0b\x32\x1f.vitis.ai.proto.AttributeResultH\x00\x12\x39\n\x11refine_det_result\x18\x04 \x01(\x0b\x32\x1c.vitis.ai.proto.DetectResultH\x00\x12\x45\n\x15\x63lassification_result\x18\x05 \x01(\x0b\x32$.vitis.ai.proto.ClassificationResultH\x00\x12\x39\n\x0froadline_result\x18\x06 \x01(\x0b\x32\x1e.vitis.ai.proto.RoadlineResultH\x00\x12\x41\n\x13\x66\x61\x63\x65landmark_result\x18\x07 \x01(\x0b\x32\".vitis.ai.proto.FaceLandmarkResultH\x00\x12@\n\x13plate_detect_result\x18\x08 \x01(\x0b\x32!.vitis.ai.proto.PlateDetectResultH\x00\x12@\n\x13plate_number_result\x18\t \x01(\x0b\x32!.vitis.ai.proto.PlateNumberResultH\x00\x12>\n\x12plate_recog_result\x18\n \x01(\x0b\x32 .vitis.ai.proto.PlateRecogResultH\x00\x12>\n\x12pose_detect_result\x18\x0b \x01(\x0b\x32 .vitis.ai.proto.PoseDetectResultH\x00\x12@\n\x13\x66\x61\x63\x65_feature_result\x18\x0c \x01(\x0b\x32!.vitis.ai.proto.FaceFeatureResultH\x00\x12@\n\x13segmentation_result\x18\r \x01(\x0b\x32!.vitis.ai.proto.SegmetationResultH\x00\x12O\n\x1bmedical_segmentation_result\x18\x0e \x01(\x0b\x32(.vitis.ai.proto.MedicalSegmetationResultH\x00\x12;\n\x10multitask_result\x18\x0f \x01(\x0b\x32\x1f.vitis.ai.proto.MultiTaskResultH\x00\x12\x31\n\x0breid_result\x18\x10 \x01(\x0b\x32\x1a.vitis.ai.proto.ReidResultH\x00\x12I\n\x18\x66\x61\x63\x65_detect_recog_result\x18\x11 \x01(\x0b\x32%.vitis.ai.proto.FaceDetectRecogResultH\x00\x12L\n\x1cvehicleclassification_result\x18\x12 \x01(\x0b\x32$.vitis.ai.proto.ClassificationResultH\x00\x42\x12\n\x10\x64pu_model_resultb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vitis.ai.proto.dpu_model_param_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _YOLOV3PARAM._serialized_start=57
  _YOLOV3PARAM._serialized_end=341
  _YOLOV3PARAM_TYPE._serialized_start=279
  _YOLOV3PARAM_TYPE._serialized_end=341
  _MEDICALPRIORBOXPARAM._serialized_start=344
  _MEDICALPRIORBOXPARAM._serialized_end=503
  _PRIORBOXPARAM._serialized_start=506
  _PRIORBOXPARAM._serialized_end=729
  _SSDPARAM._serialized_start=732
  _SSDPARAM._serialized_end=1161
  _SSDPARAM_OUTPUTINFO._serialized_start=1006
  _SSDPARAM_OUTPUTINFO._serialized_end=1098
  _SSDPARAM_OUTPUTTYPE._serialized_start=1100
  _SSDPARAM_OUTPUTTYPE._serialized_end=1161
  _RETINANETPARAM._serialized_start=1163
  _RETINANETPARAM._serialized_end=1264
  _FAIRMOTPARAM._serialized_start=1266
  _FAIRMOTPARAM._serialized_end=1382
  _MOVENETPARAM._serialized_start=1384
  _MOVENETPARAM._serialized_end=1465
  _REFINEDETPARAM._serialized_start=1468
  _REFINEDETPARAM._serialized_end=1663
  _TFREFINEDETPARAM._serialized_start=1666
  _TFREFINEDETPARAM._serialized_end=1906
  _MEDICALREFINEDETPARAM._serialized_start=1909
  _MEDICALREFINEDETPARAM._serialized_end=2403
  _MEDICALREFINEDETPARAM_OUTPUTINFO._serialized_start=2215
  _MEDICALREFINEDETPARAM_OUTPUTINFO._serialized_end=2320
  _MEDICALREFINEDETPARAM_OUTPUTTYPE._serialized_start=2322
  _MEDICALREFINEDETPARAM_OUTPUTTYPE._serialized_end=2403
  _REIDPARAM._serialized_start=2405
  _REIDPARAM._serialized_end=2471
  _OPENPOSEPARAM._serialized_start=2473
  _OPENPOSEPARAM._serialized_end=2508
  _CLASSIFICATIONPARAM._serialized_start=2511
  _CLASSIFICATIONPARAM._serialized_end=3039
  _CLASSIFICATIONPARAM_AVGPOOLPARAM._serialized_start=2763
  _CLASSIFICATIONPARAM_AVGPOOLPARAM._serialized_end=2792
  _CLASSIFICATIONPARAM_PREPROCESSTYPE._serialized_start=2795
  _CLASSIFICATIONPARAM_PREPROCESSTYPE._serialized_end=3039
  _DENSEBOXPARAM._serialized_start=3041
  _DENSEBOXPARAM._serialized_end=3126
  _MULTITASKPARAM._serialized_start=3129
  _MULTITASKPARAM._serialized_end=3489
  _ROADLINEPARAM._serialized_start=3492
  _ROADLINEPARAM._serialized_end=3857
  _RCANPARAM._serialized_start=3859
  _RCANPARAM._serialized_end=3885
  _ROADLINEDEEPHIPARAM._serialized_start=3888
  _ROADLINEDEEPHIPARAM._serialized_end=4047
  _SEGMENTATIONPARAM._serialized_start=4049
  _SEGMENTATIONPARAM._serialized_end=4174
  _PLATENUMPARAM._serialized_start=4176
  _PLATENUMPARAM._serialized_end=4250
  _SOLOPARAM._serialized_start=4253
  _SOLOPARAM._serialized_end=4445
  _LANEPARAM._serialized_start=4447
  _LANEPARAM._serialized_end=4511
  _BLINKERPARAM._serialized_start=4514
  _BLINKERPARAM._serialized_end=4687
  _SEGDETPARAM._serialized_start=4690
  _SEGDETPARAM._serialized_end=4862
  _FACEQUALITY5PTPARAM._serialized_start=4865
  _FACEQUALITY5PTPARAM._serialized_end=4994
  _RETINAFACEPARAM._serialized_start=4997
  _RETINAFACEPARAM._serialized_end=5639
  _RETINAFACEPARAM_OUTPUTANCHORINFO._serialized_start=5194
  _RETINAFACEPARAM_OUTPUTANCHORINFO._serialized_end=5285
  _RETINAFACEPARAM_OUTPUTINFO._serialized_start=5288
  _RETINAFACEPARAM_OUTPUTINFO._serialized_end=5466
  _RETINAFACEPARAM_ANCHORPARAM._serialized_start=5468
  _RETINAFACEPARAM_ANCHORPARAM._serialized_end=5548
  _RETINAFACEPARAM_OUTPUTTYPE._serialized_start=5550
  _RETINAFACEPARAM_OUTPUTTYPE._serialized_end=5609
  _RETINAFACEPARAM_ANCHORTYPE._serialized_start=5611
  _RETINAFACEPARAM_ANCHORTYPE._serialized_end=5639
  _DPUKERNELPARAM._serialized_start=5641
  _DPUKERNELPARAM._serialized_end=5700
  _TFSSDPARAM._serialized_start=5703
  _TFSSDPARAM._serialized_end=5944
  _TFSSDPARAM_OUTPUTINFO._serialized_start=5803
  _TFSSDPARAM_OUTPUTINFO._serialized_end=5897
  _TFSSDPARAM_OUTPUTTYPE._serialized_start=1100
  _TFSSDPARAM_OUTPUTTYPE._serialized_end=1145
  _POINTPILLARSNUSPARAM._serialized_start=5947
  _POINTPILLARSNUSPARAM._serialized_end=6626
  _POINTPILLARSNUSPARAM_ANCHORINFO._serialized_start=6332
  _POINTPILLARSNUSPARAM_ANCHORINFO._serialized_end=6626
  _POINTPILLARSNUSPARAM_ANCHORINFO_RANGES._serialized_start=6566
  _POINTPILLARSNUSPARAM_ANCHORINFO_RANGES._serialized_end=6596
  _POINTPILLARSNUSPARAM_ANCHORINFO_SIZES._serialized_start=6598
  _POINTPILLARSNUSPARAM_ANCHORINFO_SIZES._serialized_end=6626
  _SEGMENTATION3DPARAM._serialized_start=6628
  _SEGMENTATION3DPARAM._serialized_end=6669
  _YOLOV5PARAM._serialized_start=6671
  _YOLOV5PARAM._serialized_end=6793
  _YOLOV6PARAM._serialized_start=6796
  _YOLOV6PARAM._serialized_end=7060
  _YOLOV7PARAM._serialized_start=7062
  _YOLOV7PARAM._serialized_end=7183
  _YOLOV8PARAM._serialized_start=7186
  _YOLOV8PARAM._serialized_end=7351
  _FCOSPARAM._serialized_start=7354
  _FCOSPARAM._serialized_end=7578
  _BTSPARAM._serialized_start=7580
  _BTSPARAM._serialized_end=7705
  _POINTPILLARSBASEPARAM._serialized_start=7708
  _POINTPILLARSBASEPARAM._serialized_end=7867
  _POINTPILLARSKITTIPARAM._serialized_start=7869
  _POINTPILLARSKITTIPARAM._serialized_end=7946
  _X_AUTONOMOUS3DPARAM._serialized_start=7949
  _X_AUTONOMOUS3DPARAM._serialized_end=8567
  _X_AUTONOMOUS3DPARAM_CENTERPOINTOUTPUTLAYER._serialized_start=8384
  _X_AUTONOMOUS3DPARAM_CENTERPOINTOUTPUTLAYER._serialized_end=8567
  _EFFICIENTDETD2PARAM._serialized_start=8570
  _EFFICIENTDETD2PARAM._serialized_end=9155
  _EFFICIENTDETD2PARAM_OUTPUTINFO._serialized_start=8844
  _EFFICIENTDETD2PARAM_OUTPUTINFO._serialized_end=8947
  _EFFICIENTDETD2PARAM_ANCHORINFO._serialized_start=8950
  _EFFICIENTDETD2PARAM_ANCHORINFO._serialized_end=9108
  _EFFICIENTDETD2PARAM_OUTPUTTYPE._serialized_start=1100
  _EFFICIENTDETD2PARAM_OUTPUTTYPE._serialized_end=1145
  _SUBGRAPHPARAM._serialized_start=9158
  _SUBGRAPHPARAM._serialized_end=9356
  _SUBGRAPHPARAM_INPUTPARAM._serialized_start=9270
  _SUBGRAPHPARAM_INPUTPARAM._serialized_end=9356
  _DPUMODELPARAM._serialized_start=9359
  _DPUMODELPARAM._serialized_end=12609
  _DPUMODELPARAM_MODELTYPE._serialized_start=11767
  _DPUMODELPARAM_MODELTYPE._serialized_end=12550
  _DPUMODELPARAM_ORDERTYPE._serialized_start=12552
  _DPUMODELPARAM_ORDERTYPE._serialized_end=12609
  _DPUMODELPARAMLIST._serialized_start=12611
  _DPUMODELPARAMLIST._serialized_end=12676
  _ATTRIBUTE._serialized_start=12678
  _ATTRIBUTE._serialized_end=12734
  _POINT._serialized_start=12736
  _POINT._serialized_end=12765
  _SIZE._serialized_start=12767
  _SIZE._serialized_end=12804
  _BOUNDINGBOX._serialized_start=12807
  _BOUNDINGBOX._serialized_end=12949
  _ATTRIBUTERESULT._serialized_start=12951
  _ATTRIBUTERESULT._serialized_end=13014
  _LANDMARKRESULT._serialized_start=13016
  _LANDMARKRESULT._serialized_end=13114
  _DETECTRESULT._serialized_start=13116
  _DETECTRESULT._serialized_end=13181
  _LINEATTRIBUTE._serialized_start=13183
  _LINEATTRIBUTE._serialized_end=13250
  _ROADLINERESULT._serialized_start=13252
  _ROADLINERESULT._serialized_end=13323
  _SCORE._serialized_start=13325
  _SCORE._serialized_end=13362
  _CLASSIFICATIONLABEL._serialized_start=13364
  _CLASSIFICATIONLABEL._serialized_end=13429
  _CLASSIFICATIONRESULT._serialized_start=13431
  _CLASSIFICATIONRESULT._serialized_end=13504
  _FACELANDMARKRESULT._serialized_start=13506
  _FACELANDMARKRESULT._serialized_end=13564
  _PLATEDETECTRESULT._serialized_start=13566
  _PLATEDETECTRESULT._serialized_end=13636
  _PLATENUMBERRESULT._serialized_start=13638
  _PLATENUMBERRESULT._serialized_end=13700
  _PLATERECOGRESULT._serialized_start=13702
  _PLATERECOGRESULT._serialized_end=13814
  _POSEDETECTRESULT._serialized_start=13817
  _POSEDETECTRESULT._serialized_end=14431
  _FACEFEATURERESULT._serialized_start=14433
  _FACEFEATURERESULT._serialized_end=14503
  _FACEDETECTRECOGRESULT._serialized_start=14505
  _FACEDETECTRECOGRESULT._serialized_end=14631
  _SEGMETATIONRESULT._serialized_start=14633
  _SEGMETATIONRESULT._serialized_end=14666
  _MEDICALSEGMETATIONRESULT._serialized_start=14668
  _MEDICALSEGMETATIONRESULT._serialized_end=14751
  _VEHICLERESULT._serialized_start=14753
  _VEHICLERESULT._serialized_end=14866
  _MULTITASKRESULT._serialized_start=14869
  _MULTITASKRESULT._serialized_end=14998
  _REIDRESULT._serialized_start=15000
  _REIDRESULT._serialized_end=15026
  _DPUMODELRESULT._serialized_start=15029
  _DPUMODELRESULT._serialized_end=16234
# @@protoc_insertion_point(module_scope)



#!/usr/bin/env python
# coding=utf-8
"""
Copyright 2022-2023 Advanced Micro Devices Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""


import numpy as np
import tools_extra_ops as tools


def mem_read(args):
    np.array(tools.mem_read(args.addr, args.size), dtype=np.uint8).tofile(args.file)


def mem_write(args):
    input_data = np.fromfile(args.file, dtype=np.uint8, count=args.size)
    tools.mem_write(input_data.tolist(), args.addr)


def mem_main(args):
    if args.read:
        mem_read(args)
    elif args.write:
        mem_write(args)


def help(subparsers):
    parser = subparsers.add_parser(
        "mem",
        description="mem ",
        help="<-r|-w> <addr> <size> <output_file|input_file>",
    )
    parser.add_argument(
        "-r",
        "--read",
        help="Read memory, -r or -w must be selected",
        action="store_true",
    )
    parser.add_argument(
        "-w",
        "--write",
        help="Write memory, -r or -w must be selected",
        action="store_true",
    )
    parser.add_argument("addr", type=int, help="Address to read or write data")
    parser.add_argument("size", type=int, help="The size of the data read or written")
    parser.add_argument(
        "file",
        help="When using -r is the output file path, when using -w is the input file path",
    )
    parser.set_defaults(func=mem_main)



#!/usr/bin/env python
# coding=utf-8
"""
Copyright 2022-2023 Advanced Micro Devices Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
import os
import struct


def validate_file(file_name):
    if file_name is None:
        return "file name should not be null."
    if not os.path.exists(file_name):
        return file_name + " file doesn't exist."
    if not os.path.isfile(file_name):
        return file_name + " is not a file."
    if os.path.getsize(file_name) % 4:
        return "file size error, not a standard float data bin file."
    return


def main(args):
    # validation check for input golden file
    valid = validate_file(args.golden_file)
    if valid is not None:
        print("golden file check:", valid)
        return
    # validation check for input dump file
    valid = validate_file(args.dump_file)
    if valid is not None:
        print("dump file check:", valid)
        return
    # validation check for threshold
    if args.threshold >= 100:
        print("threshold check: threshold must be less than 100.")
        return

    # get and compare file size
    g_file_size = os.path.getsize(args.golden_file)
    d_file_size = os.path.getsize(args.dump_file)
    if g_file_size != d_file_size:
        print("float bin files have different file size.",
              '\n',
              "golden file and dump file are different!",
              sep='')
        return

    # flag to show more information
    verb = False
    if args.verbose:
        verb = True

    if verb:
        print("float file to compare: ")
        print('\t', "golden file name: " + args.golden_file + ", file size is",
              g_file_size)
        print('\t', "dump file name: " + args.dump_file + ", file size is", d_file_size)
        print('\t', "relative error threshold: " + str(args.threshold) + "%")

    # float number to compare
    floatnum = g_file_size // 4
    filesize = g_file_size
    if verb:
        print("float data number to compare is", floatnum)

    # read bin and convert to float
    with open(args.golden_file, 'br') as gf:
        goldendata = struct.unpack('f' * (floatnum), gf.read(filesize))
    with open(args.dump_file, 'br') as df:
        dumpdata = struct.unpack('f' * (floatnum), df.read(filesize))

    # comparison
    is_diff = False
    diff_index = []
    for idx in range(floatnum):
        if (goldendata[idx] - dumpdata[idx]) == 0.0:
            continue
        if goldendata[idx] == 0.0 or \
           dumpdata[idx] == 0.0 or \
           (abs((goldendata[idx] - dumpdata[idx]) / goldendata[idx]) * 100 > args.threshold):
            is_diff = True
            diff_index.append(idx)

    # result output
    print("float bin file comparison done.")
    if is_diff:
        print("golden file and dump file are different!")
        if verb:
            print("\ndifferent float index list:")
            print("index", "golden", "dump", sep='\t\t')
            for i in diff_index:
                print(i, goldendata[i], dumpdata[i], sep='\t\t')
    else:
        print("golden file and dump file are the same!")


def help(subparsers):
    parser = subparsers.add_parser(
        "comp_float",
        help="<golden_file> <dump_file> [-t threshold] [--verbose]",
    )
    parser.add_argument(
        "golden_file",
        type=str,
        help=
        "the name of input golden bin file, the file will be parsed as float data by every 4 bytes"
    )
    parser.add_argument(
        "dump_file",
        type=str,
        help=
        "the name of input dump bin file, the file will be parsed as float data by every 4 bytes"
    )
    parser.add_argument(
        "-t",
        "--threshold",
        type=float,
        default=0.01,
        help=
        "relative error threshold, range [0,100), default 0.01, this threshold should be the percentage multiplied by 100"
    )
    parser.add_argument(
        "--verbose",
        action='store_true',
        help=
        "verbose, if this argument is present, more procedure information will be shown")
    parser.set_defaults(func=main)



"""
Copyright 2022-2023 Advanced Micro Devices Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
from typing import List
import cv2
import numpy as np
import sys
import math
import xir
import vitis_ai_library
"""
 pre-process for resnet_v1_50_tf (tensorflow)
"""
_B_MEAN = 103.94
_G_MEAN = 116.78
_R_MEAN = 123.68
MEANS = [_B_MEAN, _G_MEAN, _R_MEAN]
SCALES = [1.0, 1.0, 1.0]

def resize_shortest_edge(image, smallest_side):
    H, W = image.shape[:2]
    if H >= W:
        nW = smallest_side
        nH = int(float(H)/W * smallest_side)
    else:
        nH = smallest_side
        nW = int(float(W)/H * smallest_side)
    #print("nW:nH=",nW,nH)
    return cv2.resize(image,(nW,nH))

def crop_image(image, height, width):
    image_height = image.shape[0]
    image_width = image.shape[1]
    offset_height = (image_height - height) // 2
    offset_width = (image_width - width) // 2
    return image[offset_height:offset_height + height, offset_width:offset_width + width, :]

def preprocess_one_image(image_path, width, height, means, scales, fixpos):
    image = cv2.imread(image_path)
    image = resize_shortest_edge(image, 256)
    image = crop_image(image, height, width)
    B, G, R = cv2.split(image)
    fix_scale = 2**fixpos
    B = (B - means[0]) * (scales[0] * fix_scale)
    G = (G - means[1]) * (scales[1] * fix_scale)
    R = (R - means[2]) * (scales[2] * fix_scale)
    image = cv2.merge([R, G, B])
    image = image.astype(np.int8)
    return image


"""
Get topk results according to its probability
datain: data result of graph_runner
filePath: filePath in which that records the infomation of kinds
"""


def TopK(datain, size, filePath):
    cnt = [i for i in range(size)]
    pair = zip(datain, cnt)
    pair = sorted(pair, reverse=True)
    softmax_new, cnt_new = zip(*pair)
    fp = open(filePath, "r")
    data1 = fp.readlines()
    fp.close()
    for i in range(5):
        idx = 0
        for line in data1:
            if idx == cnt_new[i]:
                print("Top[%d] %d %f %s" % (i, idx, softmax_new[i], (line.strip)("\n")))
            idx = idx + 1


def main(argv):
    """create_graph_runner """
    g = xir.Graph.deserialize(argv[1])
    runner = vitis_ai_library.GraphRunner.create_graph_runner(g)
    """get_inputs & get_outputs"""
    input_tensor_buffers = runner.get_inputs()
    output_tensor_buffers = runner.get_outputs()

    input_ndim = tuple(input_tensor_buffers[0].get_tensor().dims)
    batch = input_ndim[0]
    height = input_ndim[1]
    width = input_ndim[2]
    fixpos = input_tensor_buffers[0].get_tensor().get_attr("fix_point")
    """init input data """
    image = preprocess_one_image(argv[2], width, height, MEANS, SCALES, fixpos)
    input_data = np.asarray(input_tensor_buffers[0])
    input_data[0] = image
    """ run graph runner"""
    job_id = runner.execute_async(input_tensor_buffers, output_tensor_buffers)
    runner.wait(job_id)

    pre_output_size = int(
        output_tensor_buffers[0].get_tensor().get_element_num() / batch)
    output_data = np.asarray(output_tensor_buffers[0])
    """post-process"""
    TopK(output_data[0], pre_output_size, "./words.txt")
    del runner


if __name__ == "__main__":
    if len(sys.argv) != 3:
        print("please model file and input file.")
    else:
        main(sys.argv)



#!/usr/bin/env python
# coding=utf-8
"""
Copyright 2022-2023 Advanced Micro Devices Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

import xir
import os
import sys
import os
from typing import List
import tools_extra_ops as tools
import hashlib
import json
import numpy as np


def png(args):
    xir.Graph.deserialize(args.xmodel).save_as_image(args.png, "png")


def svg(args):
    xir.Graph.deserialize(args.xmodel).save_as_image(args.svg, "svg")


def txt(args):
    import tools_extra_ops as tools

    res = tools.xmodel_to_txt(args.xmodel)
    if args.txt != sys.stdout:
        open(args.txt, mode="w").write(res)
    else:
        print(res)


def get_op_output_tensor_ddr(op: "Op", s: "Subgraph"):
    tensor = op.get_output_tensor()
    if op.get_type() == "download" and op in s.get_ops():
        input_ops = op.get_input_ops_by_name("input")
        assert len(input_ops) == 1, "There must be only one pre_op for download op."
        tensor = input_ops[0].get_output_tensor()
    elif not tensor.has_attr("reg_id") or not op in s.get_ops():
        ops = list(set(op.get_fanout_ops()) & s.get_ops())
        assert len(ops) == 1, ("illegal xmodel. op:" + op.get_name() +
                               "  has no ddr info")
        assert ops[0].get_type() == "upload", ("illegal xmodel. op:" + op.get_name() +
                                               "  has no ddr info")
        tensor = ops[0].get_output_tensor()
    assert tensor.has_attr("reg_id"), "op_name " + op.get_name()
    reg_id = tensor.get_attr("reg_id")

    return reg_id


def get_tensor_ddr_info(s: "Subgraph", tensors):
    return {get_op_output_tensor_ddr(t.producer, s) for t in tensors}


def create_dpu_result(s: "Subgraph"):
    result_s = {}
    result_s["fingerprint"] = (hex(0) if not s.has_attr("dpu_fingerprint") else hex(
        s.get_attr("dpu_fingerprint")))
    result_s["DPU Arch"] = s.get_attr("dpu_name")
    result_s["workload"] = s.get_attr("workload")

    input_tensors = list(s.get_input_tensors())
    input_tensors.sort(key=lambda tensor: tensor.name)

    result_s["input_tensor"] = [{
        "index": idx,
        "name": t.name,
        "shape": t.dims,
        "fixpos": t.get_attr("fix_point"),
    } for idx, t in enumerate(input_tensors)]
    result_s["output_tensor"] = [{
        "index": idx,
        "name": t.name,
        "shape": t.dims,
        "fixpos": t.get_attr("fix_point"),
    } for idx, t in enumerate(s.get_output_tensors())]
    # result_s["subgraph"] = [c.get_name() for c in s.toposort_child_subgraph()]
    """
    if s.has_attr("reg_id_to_context_type"):
        cont_type = s.get_attr("reg_id_to_context_type")
        table = {k: [v] for k, v in cont_type.items()}
    """
    input_id_set = get_tensor_ddr_info(s, s.get_input_tensors())
    output_id_set = get_tensor_ddr_info(s, s.get_output_tensors())
    cont_type = {}
    if s.has_attr("reg_id_to_context_type_v2"):
        cont_type_2 = s.get_attr("reg_id_to_context_type_v2")
        for k, v in cont_type_2.items():
            if v == "INTERFACE":
                reg_id = int(k.replace("REG_",""))
                if reg_id in input_id_set and reg_id in output_id_set:
                    v = "DATA_LOCAL"
                elif reg_id in input_id_set:
                    v = "DATA_LOCAL_INPUT"
                elif reg_id in output_id_set:
                    v = "DATA_LOCAL_OUTPUT"
                else:
                    v = "INVALID TYPE: " + v
            cont_type[k] = v
    elif s.has_attr("reg_id_to_context_type"):
        cont_type = s.get_attr("reg_id_to_context_type")

    pmd5 = tools.get_reg_id_to_parameter(s)

    size = {}
    if s.has_attr("reg_id_to_size"):
        size = s.get_attr("reg_id_to_size")
        # for k, v in size.items():
        #     size[k] = str(round(v / 1024.0 / 1024.0, 2)) + "MB"

    keys = list(set(list(cont_type.keys()) + list(pmd5.keys()) + list(size.keys())))
    keys.sort()
    table = [
        {
            "name": k,
            "context type": cont_type.get(k),
            # "parameter md5 value": pmd5.get(k),
            "size": size.get(k),
        } for k in keys
    ]

    result_s["reg info"] = table

    if s.has_attr("mc_code"):
        ins_reg = s.get_attr("mc_code")
        result_s["instruction reg"] = len(ins_reg)

    return result_s


def get_child_subgraph(graph: "Graph") -> List["Subgraph"]:
    """
    obtain subgrah
    """
    assert graph is not None, "'graph' should not be None."
    root_subgraph = graph.get_root_subgraph()
    assert (root_subgraph
            is not None), "Failed to get root subgraph of input Graph object."
    if root_subgraph.is_leaf:
        return []
    return root_subgraph.toposort_child_subgraph()


def glist(xmodel_path: "String"):
    graph = xir.Graph.deserialize(xmodel_path)
    res = {}
    res["subgraphs"] = []
    idx = 0
    for cs in get_child_subgraph(graph):
        device = "" if not cs.has_attr("device") else cs.get_attr("device").upper()
        if device:
            result_s = {}
            result_s["index"] = idx
            idx += 1
            result_s["name"] = cs.get_name()
            result_s["device"] = device
            if device == "DPU":
                result_s = dict(result_s, **create_dpu_result(cs))
            res["subgraphs"].append(result_s)

    print(json.dumps(res, sort_keys=False, indent=4, separators=(",", ":")))


input_args_type = ("input", "weights", "bias")
# attrs_filter_out = ("data", "quant_out_signed", "quant_out_round_mode", "quant_in_signed")


def op_info(xmodel: "String", op_name: "String"):
    print("xmodel: ", xmodel)
    print("op_name: ", op_name)
    graph = xir.Graph.deserialize(xmodel)
    op = graph.get_op(op_name)
    if op is None:
        print("Error: op name doesn't exist in the model!")
        return

    res = {}
    res["name"] = op.get_name()
    res["type"] = op.get_type()
    op_attrs = op.get_attrs()
    filter_attrs = {}
    for k, v in op_attrs.items():
        if k != "data" and not k.startswith("quant_"):
            filter_attrs[k] = v

    # for attr in attrs_filter_out:
    #     if op_attrs.get(attr) is not None:
    #         op_attrs.pop(attr)

    res["attrs"] = filter_attrs
    input_ops = op.get_input_ops()
    op_list = []
    if len(input_ops):
        op_index = 0
        for arg in input_args_type:
            if input_ops.get(arg) is not None:
                args = input_ops[arg]
                for idx in args:
                    op_dict = {}
                    op_dict["index"] = op_index
                    op_index += 1
                    op_dict["op_name"] = idx.get_name()
                    op_dict["tensor_name"] = idx.get_output_tensor().name
                    op_dict["shape"] = idx.get_output_tensor().dims
                    op_dict["data_type"] = idx.get_output_tensor().dtype
                    op_list.append(op_dict)
    res["inputs"] = op_list

    out_res = {}
    out_res["op_name"] = op.get_name()
    out_res["tensor_name"] = op.get_output_tensor().name
    out_res["shape"] = op.get_output_tensor().dims
    out_res["data_type"] = op.get_output_tensor().dtype
    out_res_attrs = {}
    for k, v in op.get_output_tensor().get_attrs().items():
        if not k.startswith("quant_"):
            out_res_attrs[k] = v
    out_res["attrs"] = out_res_attrs
    res["outputs"] = out_res

    print(json.dumps(res, sort_keys=False, indent=4, separators=(",", " : ")))


def meta_info(xmodel_path):
    graph = xir.Graph.deserialize(xmodel_path).get_attrs()
    for k in list(graph["files_md5sum"].keys()):
        graph["files_md5sum"][k.split("/")[-1]] = graph["files_md5sum"].pop(k)

    for k in graph["files_md5sum"].keys():
        if k.find("_org.xmodel") != -1:
            graph["files_md5sum"].pop(k)
            break

    print(json.dumps(graph, sort_keys=True, indent=4, separators=(",", ":")))


def node_id(i):
    return 'node{0}'.format(i)


def get_attr(tensor, attr_name, default_value):
    if not tensor.has_attr(attr_name):
        return default_value
    return tensor.get_attr(attr_name)


def node_label(i, sg):
    return '''{0}: {1}'''.format(i, sg.get_name())


def find_subgraph_id(g, tensor, sgs):
    op = g.get_tensor_producer(tensor)
    s = g.get_leaf_subgraph(op)
    index = -1
    while not s == g.get_root_subgraph():
        try:
            index = sgs.index(s)
            break
        except ValueError:
            s = s.get_parent()
    assert not index == -1
    return index


def tensor_label(tensor):
    return '''
name: {0}
type: {1}
fix_point: {2}
shape: {3}
'''.format(tensor.name, tensor.producer.get_type(), get_attr(tensor, 'fix_point', 'N/A'),
           tensor.dims)


def subgraph_svg(xmodel_path: "String", svg_file: "String"):
    graph = xir.Graph.deserialize(xmodel_path)
    from graphviz import Digraph
    g = Digraph()  # comment='The Round Table')
    g.attr(compound='true')
    sgs = graph.get_root_subgraph().toposort_child_subgraph()
    i = 0
    for sg in sgs:
        with g.subgraph(name='cluster%d' % (i, )) as c:
            c.attr('node', shape='plaintext')
            c.attr(label=sg.get_name())
            # node_label(i, sg))
            c.node(node_id(i), label=sg.get_attr('device'))
            output_tensors = list(sg.get_output_tensors())
            output_tensors.sort(key=lambda tensor: tensor.name)
            for tensor in output_tensors:
                c.attr('node', shape='box')
                c.node(tensor.name, tensor_label(tensor))
                c.edge(node_id(i), tensor.name)
        i = i + 1
    i = 0
    for sg in sgs:
        for tensor in sg.get_input_tensors():
            g.edge(tensor.name, node_id(i), lhead="cluster%d" % (i, ))
        i = i + 1
    filename, file_extension = os.path.splitext(svg_file)
    file_extension = file_extension[1:]  # remove "."
    g.render(filename=filename, cleanup=False, format=file_extension)


def binary(xmodel_path: "String", output_directory: "String"):
    graph = xir.Graph.deserialize(xmodel_path)
    children = graph.get_root_subgraph().toposort_child_subgraph()
    index = 0
    for sg in children:
        sg_path = os.path.join(output_directory, "sg_{}".format(index))
        os.makedirs(sg_path, exist_ok=True)
        if sg.has_attr('mc_code'):
            buf = tools.xir_get_attr_binary(sg, 'mc_code')
            array = np.array(buf, copy=False)
            filename = os.path.join(sg_path, "mc_code.bin")
            print("write to {}".format(filename))
            array.tofile(filename)
        if sg.has_attr('reg_id_to_parameter_value'):
            map_buf = tools.xir_get_attr_map_binary(sg, "reg_id_to_parameter_value")
            for (key, buf) in map_buf.items():
                array = np.array(buf, copy=False)
                filename = os.path.join(sg_path, "{}.bin".format(key))
                print("write to {}".format(filename))
                array.tofile(filename)


def xmodel_main(args):
    if args.png:
        png(args)
    elif args.svg:
        svg(args)
    elif args.txt:
        txt(args)
    elif args.list:
        glist(args.xmodel)
    elif args.op:
        op_info(args.xmodel, args.op)
    elif args.meta_info:
        meta_info(args.xmodel)
    elif args.subgraph_svg:
        subgraph_svg(args.xmodel, args.subgraph_svg)
    elif args.binary:
        binary(args.xmodel, args.binary)


def help(subparsers):
    parser = subparsers.add_parser(
        "xmodel",
        description="xmodel ",
        help=
        "<xmodel> [-h] | [-l] | [-m] | [-p png] | [-s svg] | [-t txt] | [--op op_name]",
    )
    parser.add_argument("xmodel", help="xmodel file path ")
    parser.add_argument(
        "-l",
        "--list",
        help="show subgraph list",
        action="store_true",
    )
    parser.add_argument(
        "--op",
        help="show op info",
        nargs="?",
    )
    parser.add_argument(
        "-m",
        "--meta_info",
        help="show xcompiler version",
        action="store_true",
    )
    parser.add_argument(
        "-p",
        "--png",
        help="the output to png ",
        nargs="?",
        const="default.png",
    )
    parser.add_argument(
        "-s",
        "--svg",
        help="the output svg path ",
        nargs="?",
        const="default.svg",
    )
    parser.add_argument(
        "-S",
        "--subgraph_svg",
        help="the output svg for subgraph level ",
        nargs="?",
        const="subgraph.svg",
    )
    parser.add_argument(
        "-t",
        "--txt",
        help="when <txt> is missing, it dumps to standard output.",
        nargs="?",
        const=sys.stdout,
    )
    parser.add_argument(
        "-b",
        "--binary",
        help=
        '''dump the binary data to the output directory, when <binary> is missing, it dumps to 'binary' directory''',
        nargs="?",
        const="binary",
    )

    parser.set_defaults(func=xmodel_main)
